@@ -1,6 +1,5 @@
-import logging
 from typing import List, Any, Tuple
-from os import environ
+import logging
 
 from qtpy.QtCore import QObject, Signal, Qt
 from qtpy.QtGui import QBrush
@@ -211,7 +210,7 @@ class GraphManager(Display, metaclass=Singleton):
             try:
                 graph.update(data, slice(last_data_size, None))
             except Exception as ex:
-                logging.exception(ex)
+                logger.exception(ex)
 
     def clear(self):
         for graph in self.graphs:
